==> v8.3.zip: ru_twords_ru_tw/bible/other/sword.md <==
# меч, оруженосец

## Определение:

Меч — это металлическое оружие с плоским клинком, использующееся для нанесения колющих или режущих ран. Меч состоит из рукоятки и остроконечного лезвия с острой режущей кромкой.

* В древности мечи обычно были длиной от шестидесяти до девяноста сантиметров. Существовали также двуручные мечи, которые были ещё длиннее.
* У некоторых мечей лезвие оттачивалось с обеих сторон. Такие мечи назывались “обоюдоострыми”.
* У учеников Иисуса были мечи, которые они носили с собой для защиты. Пётр своим мечом отсёк ухо раба первосвященника.
* Иоанн Креститель и апостол Иаков были обезглавлены мечами.

## Варианты перевода:

* В Библии слово “меч” используется как в прямом, так и в переносном значении. Во втором случае “меч” — это метафора для описания Божьего Слова. Божье учение в Библии подобно мечу, который вскрывает сокровенные мысли человека и обличает его в грехе. (См.: [Metaphor](rc://*/ta/man/translate/figs-metaphor))
* Когда слово “меч” сравнивается с Божьим Словом, можно использовать такой перевод: “Божье Слово подобно мечу, который глубоко проникает и вскрывает грех”.
* В Библии встречается иное переносное значение слова “меч”. Речь идёт о книге Псалмов, где сказано, что когда человеческие язык или речь сравниваются с мечом, имеется в виду, что ими можно ранить человека. В этом случае можно использовать такой перевод: “язык подобен мечу, которым можно ранить человека”.
* Если этот вид оружия не известен в вашей культуре, то слово “меч” можно заменить названием другого оружия с длинным клинком.
* Когда слово “меч” используется в прямом значении, его можно перевести  словосочетаниями “острое оружие” или “длинный нож”. В некоторых случаях желательно также поместить иллюстрацию, изображающую классический меч.

(См. также: [Как переводить слова с неизвестным значением](rc://*/ta/man/translate/translate-unknown))

(См. также: [Иаков (брат Иисуса)](../names/jamesbrotherofjesus.md), [Иоанн (Креститель)](../names/johnthebaptist.md), [язык](../other/tongue.md), [слово Божье](../kt/wordofgod.md))

## Ссылки на библейский текст:

* [Деян. 12:1-2](rc://*/tn/help/act/12/01)
* [Быт. 27:39-40](rc://*/tn/help/gen/27/39)
* [Быт. 34:24-26](rc://*/tn/help/gen/34/24)
* [Лк. 2:33-35](rc://*/tn/help/luk/02/33)
* [Лк. 21:23-24](rc://*/tn/help/luk/21/23)
* [Мф. 10:34-36](rc://*/tn/help/mat/10/34)
* [Мф. 26:55-56](rc://*/tn/help/mat/26/55)
* [Откр. 1:14-16](rc://*/tn/help/rev/01/14)

## Данные о слове:

* Номера Стронга: H19, H1300, H2719, H4380, H6609, H7524, H7973, G3162, G4501

==> v9.2.zip: ru_twords_ru_tw/bible/other/sword.md <==
# меч, оруженосец

## Определение:

Меч — это металлическое оружие с плоским клинком, использующееся для нанесения колющих или режущих ран. Меч состоит из рукоятки и остроконечного лезвия с острой режущей кромкой.
* В древности мечи обычно были длиной от шестидесяти до девяноста сантиметров. Существовали также двуручные мечи, которые были ещё длиннее.
* У некоторых мечей лезвие оттачивалось с обеих сторон. Такие мечи назывались “обоюдоострыми”.
* У учеников Иисуса были мечи, которые они носили с собой для защиты. Пётр своим мечом отсёк ухо раба первосвященника.
* Иоанн Креститель и апостол Иаков были обезглавлены мечами.

## Варианты перевода:

* В Библии слово “меч” используется как в прямом, так и в переносном значении. Во втором случае “меч” — это метафора для описания Божьего Слова. Божье учение в Библии подобно мечу, который вскрывает сокровенные мысли человека и обличает его в грехе. (См.: [Metaphor](rc://ru/ta/man/translate/figs-metaphor))
* Когда слово “меч” сравнивается с Божьим Словом, можно использовать такой перевод: “Божье Слово подобно мечу, который глубоко проникает и вскрывает грех”.
* В Библии встречается иное переносное значение слова “меч”. Речь идёт о книге Псалмов, где сказано, что когда человеческие язык или речь сравниваются с мечом, имеется в виду, что ими можно ранить человека. В этом случае можно использовать такой перевод: “язык подобен мечу, которым можно ранить человека”.
* Если этот вид оружия не известен в вашей культуре, то слово “меч” можно заменить названием другого оружия с длинным клинком.
* Когда слово “меч” используется в прямом значении, его можно перевести  словосочетаниями “острое оружие” или “длинный нож”. В некоторых случаях желательно также поместить иллюстрацию, изображающую классический меч. 

(См. также: [Как переводить слова с неизвестным значением](rc://ru/ta/man/translate/translate-unknown))

(См. также: [Иаков (брат Иисуса)](../names/jamesbrotherofjesus.md), [Иоанн (Креститель)](../names/johnthebaptist.md), [язык](../other/tongue.md), [слово Божье](../kt/wordofgod.md))

## Ссылки на библейский текст:

* [Деян. 12:1-2](rc://ru/tn/help/act/12/01)
* [Быт. 27:39-40](rc://ru/tn/help/gen/27/39)
* [Быт. 34:24-26](rc://ru/tn/help/gen/34/24)
* [Лк. 2:33-35](rc://ru/tn/help/luk/02/33)
* [Лк. 21:23-24](rc://ru/tn/help/luk/21/23)
* [Мф. 10:34-36](rc://ru/tn/help/mat/10/34)
* [Мф. 26:55-56](rc://ru/tn/help/mat/26/55)
* [Откр. 1:14-16](rc://ru/tn/help/rev/01/14)

## Данные о слове:

* Номера Стронга: H19, H1300, H2719, H4380, H6609, H7524, H7973, G3162, G4501
